name2regex = {
    "url": r"((https?):((//)|(\\\\))+([\w\d:#@%/;$()~_?\+-=\\\.&](#!)?)*)",
    "emoji": (r"['\U0001F300-\U0001F5FF'|'\U0001F600-\U0001F64F'|"
              r"'\U0001F680-\U0001F6FF'|'\u2600-\u26FF\u2700-\u27BF']"),
    "hashtag": r"(\#[a-zA-Z0-9_]+\b)",
    "mention": r"(\@[a-zA-Z0-9_]+\b)",
    "email": r"([a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+)",
    "coin": r"(\$[a-zA-Z]+\b)"
}
